@@ -1,7 +1,5 @@
-from django.core.exceptions import ObjectDoesNotExist
-from rest_framework.relations import PrimaryKeyRelatedField
-
-from air_drf_relation.utils import get_related_object
+from rest_framework.relations import PrimaryKeyRelatedField, Field
+from air_drf_relation.utils import get_pk_from_data
 
 
 class AirRelatedField(PrimaryKeyRelatedField):
@@ -11,6 +9,8 @@ class AirRelatedField(PrimaryKeyRelatedField):
         self.hidden = kwargs.pop('hidden', False)
         self.queryset_function_name = kwargs.pop('queryset_function_name', None)
         self.queryset_function_disabled = kwargs.pop('queryset_function_disabled', False)
+        self.parent = None
+        kwargs.pop('as_serializer', None)
 
         if not kwargs.get('read_only'):
             self.queryset = kwargs.pop('queryset', None)
@@ -20,6 +20,12 @@ class AirRelatedField(PrimaryKeyRelatedField):
             self.queryset_function_disabled = True
 
         super().__init__(**kwargs)
+        self.parent = None
+
+    def __new__(cls, serializer, *args, **kwargs):
+        if kwargs.pop('as_serializer', False):
+            return serializer(*args, **kwargs)
+        return super().__new__(cls, serializer, *args, **kwargs)
 
     def __call__(self, *args, **kwargs):
         super.__call__(*args, **kwargs)
@@ -28,14 +34,20 @@ class AirRelatedField(PrimaryKeyRelatedField):
         return self.pk_only
 
     def to_internal_value(self, data):
-        try:
-            return get_related_object(data, queryset=self.queryset)
-        except ObjectDoesNotExist:
-            self.fail('does_not_exist', pk_value=data)
-        except (TypeError, ValueError):
-            self.fail('incorrect_type', data_type=type(data).__name__)
+        data = get_pk_from_data(data, self.queryset.model._meta.pk.name)
+        return super(AirRelatedField, self).to_internal_value(data)
 
     def to_representation(self, value):
         if not self.pk_only:
-            return self.serializer(value, context=self.context).data
+            serializer = self.serializer(value, context=self.context)
+            serializer.parent = self.parent
+            return serializer.data
         return value.pk
+
+
+class AirAnyField(Field):
+    def to_representation(self, value):
+        return value
+
+    def to_internal_value(self, data):
+        return data
