@@ -4,7 +4,7 @@ from dataclasses import asdict, is_dataclass
 import json
 
 
-class AirDataClassField(models.JSONField):
+class AirDataclassField(models.JSONField):
 
     def __init__(self, data_class, *args, **kwargs):
         self.data_class = data_class
