@@ -1,6 +1,6 @@
 from django.db import models
 from dataclasses import dataclass
-from air_drf_relation.model_fields import AirDataClassField
+from air_drf_relation.model_fields import AirDataclassField
 
 
 @dataclass
@@ -8,6 +8,7 @@ class FilmInformation:
     budget: float
     rating: str
     description: str
+    active: bool = True
     # kek: int = 1
 
 
@@ -18,5 +19,5 @@ class Actor(models.Model):
 class Film(models.Model):
     name = models.CharField(max_length=256)
     release_date = models.DateField()
-    information: FilmInformation = AirDataClassField(data_class=FilmInformation)
+    information: FilmInformation = AirDataclassField(data_class=FilmInformation)
     actors = models.ManyToManyField(Actor, related_name='films')
